@@ -1,6 +1,6 @@
 package Object::RateLimiter;
 {
-  $Object::RateLimiter::VERSION = '1.000000';
+  $Object::RateLimiter::VERSION = '1.001001';
 }
 use strictures 1;
 use Carp 'confess';
@@ -15,6 +15,14 @@ sub SECS   () { 1 }
 sub QUEUE  () { 2 }
 
 use namespace::clean;
+use overload
+  bool     => sub { 1 },
+  '&{}'    => sub {
+    my $self = shift;
+    sub { $self->delay }
+  },
+  fallback => 1;
+
 
 sub seconds  { $_[0]->[SECS]   }
 sub events   { $_[0]->[EVENTS] }
@@ -138,6 +146,9 @@ Object::RateLimiter - A flood control (rate limiter) object
   # Clear the event history unconditionally:
   $ctrl->clear;
 
+  # Same as calling ->delay:
+  my $delayed = $ctrl->();
+
 =head1 DESCRIPTION
 
 This is a generic rate-limiter object, implementing the math described in
@@ -191,6 +202,9 @@ left untouched.
     do_work;
   }
 
+  # Same as calling ->delay:
+  my $delay = $ctrl->();
+
 The C<delay()> method determines if some work can be done now, or should wait.
 
 When called, event timestamps are considered; if we have exceeded our limit,
